@@ -1,8 +1,8 @@
 #' Plot a scatter plot on a boxplot with two variables.
 #'
-#' There are three types of `plot_dot_` functions that plot "dots" as data symbols plotted with \code{\link[ggplot2]{geom_dotplot}} geometry. Variants can show summary and data distributions as bar and SD errors (\link{plot_dotbar_sd}), box and whisker plots (\link{plot_dotbox}) or violin and box & whiskers plots (\link{plot_dotviolin}). They all take a data table, a categorical X variable and a numeric Y variable. 
+#' There are three types of `plot_dot_` functions that plot "dots" as data symbols plotted with \code{\link[ggplot2]{geom_dotplot}} geometry. Variants can show summary and data distributions as bar and SD errors (\link{plot_dotbar_sd}; or SEM or CI95 error bars), box and whisker plots (\link{plot_dotbox}) or violin and box & whiskers plots (\link{plot_dotviolin}). They all take a data table, a categorical X variable and a numeric Y variable. 
 #' 
-#' Related `plot_scatter` variants show data symbols using the \code{\link[ggplot2]{geom_point}} geometry. These are \link{plot_scatterbar_sd}, \link{plot_scatterbox} and \link{plot_scatterviolin}. Overplotting in `plot_scatter` variants can be reduced with the `jitter` argument.
+#' Related `plot_scatter_` variants show data symbols using the \code{\link[ggplot2]{geom_point}} geometry. These are \link{plot_scatterbar_sd} (or SEM or CI95 error bars), \link{plot_scatterbox} and \link{plot_scatterviolin}. Overplotting in `plot_scatter` variants can be reduced with the `jitter` argument.
 #' 
 #' The X variable is mapped to the \code{fill} aesthetic of dots, symbols, bars, boxes and violins.
 #' 
@@ -34,7 +34,7 @@
 #' @param ColPal grafify colour palette to apply, default "okabe_ito"; see \code{\link{graf_palettes}} for available palettes.
 #' @param ColSeq logical TRUE or FALSE. Default TRUE for sequential colours from chosen palette. Set to FALSE for distant colours, which will be applied using  \code{scale_fill_grafify2}.
 #' @param ColRev whether to reverse order of colour within the selected palette, default F (FALSE); can be set to T (TRUE).
-#' @param SingleColour a colour hexcode (starting with #), a number between 1-154, or names of colours from `grafify` colour palettes to fill along X-axis aesthetic. Accepts any colour other than "black"; use `grey_lin11`, which is almost black.
+#' @param SingleColour a colour hexcode (starting with #), a number between 1-154, or names of colours from `grafify` or base R palettes to fill along X-axis aesthetic. Accepts any colour other than "black"; use `grey_lin11`, which is almost black.
 #' @param ... any additional arguments to pass to \code{ggplot2}[geom_boxplot].
 #'
 #' @return This function returns a \code{ggplot2} object of class "gg" and "ggplot".
@@ -54,44 +54,22 @@ plot_scatterbox <- function(data, xcol, ycol, facet, symsize = 3, s_alpha = 0.8,
   ColPal <- match.arg(ColPal)
   if (missing(bthick)) {bthick = fontsize/22}
   if (missing(symthick)) {symthick = fontsize/22}
-  if (missing(SingleColour)) {
-    P <- ggplot2::ggplot(data, aes(x = factor({{ xcol }}),
-                                   y = {{ ycol }}))+
-      geom_boxplot(aes(fill = factor({{ xcol }})), 
-                   size = bthick,
-                   alpha = b_alpha,
-                   outlier.alpha = 0,
-                   width = bwid,
-                   ...)+
-      geom_point(shape = 21,
-                 position = position_jitter(width = jitter),
-                 alpha = s_alpha,
-                 stroke = symthick,
-                 size = symsize,
-                 aes(fill = factor({{ xcol }})))+
-      labs(x = enquo(xcol),
-           fill = enquo(xcol))
-  } else {
-    ifelse(grepl("#", SingleColour), 
-           a <- SingleColour,
-           a <- get_graf_colours(SingleColour))
-    
-    P <- ggplot2::ggplot(data, aes(x = factor({{ xcol }}),
-                                   y = {{ ycol }}))+
-      geom_boxplot(fill = a, 
-                   size = bthick,
-                   alpha = b_alpha,
-                   outlier.alpha = 0,
-                   width = bwid, 
-                   ...)+
-      geom_point(shape = 21,
-                 position = position_jitter(width = jitter),
-                 alpha = s_alpha,
-                 stroke = symthick,
-                 size = symsize,
-                 fill = a)+
-      labs(x = enquo(xcol))
-  }
+  P <- ggplot2::ggplot(data, aes(x = factor({{ xcol }}),
+                                 y = {{ ycol }}))+
+    geom_boxplot(aes(fill = factor({{ xcol }})), 
+                 size = bthick,
+                 alpha = b_alpha,
+                 outlier.alpha = 0,
+                 width = bwid,
+                 ...)+
+    geom_point(shape = 21,
+               position = position_jitter(width = jitter),
+               alpha = s_alpha,
+               stroke = symthick,
+               size = symsize,
+               aes(fill = factor({{ xcol }})))+
+    labs(x = enquo(xcol),
+         fill = enquo(xcol))
   if(!missing(facet)) {
     P <- P + facet_wrap(vars({{ facet }}), 
                         scales = facet_scales, 
@@ -124,12 +102,29 @@ plot_scatterbox <- function(data, xcol, ycol, facet, symsize = 3, s_alpha = 0.8,
                            limits = LogYLimits, 
                            ...)}
   }
-  P <- P+
+  if(!missing(SingleColour)) {
+    ifelse(grepl("#", SingleColour), 
+           a <- SingleColour,
+           ifelse(isTRUE(get_graf_colours(SingleColour) != 0), 
+                  a <- unname(get_graf_colours(SingleColour)), 
+                  a <- SingleColour))
+    xcol <- deparse(substitute(xcol))
+    x <- length(levels(factor(data[[xcol]])))
+    P <- P + 
+      scale_fill_manual(values = rep(a, 
+                                     times = x))+
+      labs(x = enquo(xcol))+
+      guides(fill = "none")
+  } else {
+    P <- P + 
+      scale_fill_grafify(palette = ColPal, 
+                         reverse = ColRev, 
+                         ColSeq = ColSeq)
+    
+  }
+  P <- P +
     theme_classic(base_size = fontsize)+
     theme(strip.background = element_blank())+
-    guides(x = guide_axis(angle = TextXAngle))+
-    scale_fill_grafify(palette = ColPal, 
-                       reverse = ColRev, 
-                       ColSeq = ColSeq)
+    guides(x = guide_axis(angle = TextXAngle))
   P
 }
